##  Cloning S-User ID Authorizations
### Context
Administrators can clone an existing authorization profile by copying it from a source S-user to one or more target S-users. This ensures that all selected users are granted an identical set of authorizations.
### Procedure
  1. Go to SAP for Me.
  2. In the User Management area, go to the  Users, Requested Users, or Important Contacts tab.
  3. Search for the source S-user ID to copy authorizations from. To open the user details screen, choose anywhere in the row for that user.
If you're an administrator and copying your own authorizations to other S-user IDs, select your own S-user ID.
  4. Choose Copy Authorizations.
If you don't see this option, you aren't logged in with a super, cloud, or user administrator S-user ID
  5. Select the users to whom you want to apply the copied authorizations, and choose OK.
  6. On the Copy Options screen, choose how you want to copy the authorizations.
     * Add Authorizations: The selected users keep their existing authorizations and receive additional authorizations based on those copied from the source S-user.
     * Overwrite Authorizations: This replaces the selected users' authorizations with the authorizations from the source S-user.
  7. Choose Continue.
